@@ -3,5 +3,5 @@ from FreeTAKServer.controllers.configuration.MainConfig import MainConfig
 class CoTServiceVariables:
     def __init__(self):
         self.CoTServiceIP = "0.0.0.0"
-        self.CoTServicePort = MainConfig.CoTServicePort
+        self.CoTServicePort = MainConfig.CoTServiceIP
         self.CoTServiceStatus = ""
\ No newline at end of file
