@@ -1,5 +1,4 @@
-from abc import ABC
-class SpecificCoTAbstract(ABC):
+class SpecificCoTAbstract:
     def define_variables(self):
         self.type = None
         self.clientInformation = None
